# Security Policy

## Supported Versions

We release patches for security vulnerabilities for the following versions:

| Version | Supported          |
| ------- | ------------------ |
| 0.3.x   | :white_check_mark: |
| < 0.3   | :x:                |

## Reporting a Vulnerability

If you discover a security vulnerability within SampoNLP, please send an email to les4sixstm@gmail.com. 

All security vulnerabilities will be promptly addressed.

Please include the following information in your report:

- Type of vulnerability
- Full paths of source file(s) related to the vulnerability
- Location of the affected source code (tag/branch/commit or direct URL)
- Any special configuration required to reproduce the issue
- Step-by-step instructions to reproduce the issue
- Proof-of-concept or exploit code (if possible)
- Impact of the issue, including how an attacker might exploit it

## Response Timeline

- We will acknowledge your email within 48 hours
- We will provide a more detailed response within 7 days
- We will work on a fix and keep you updated on the progress
- Once the fix is ready, we will release a security patch and credit you (unless you prefer to remain anonymous)

Thank you for helping keep SampoNLP and its users safe!
